summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorzelidrag@chromium.org <zelidrag@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-03-06 00:45:24 +0000
committerzelidrag@chromium.org <zelidrag@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-03-06 00:45:24 +0000
commit7d1ca4dc9a9b7934b54354033addb8aae240f0c5 (patch)
tree4e5c3417f9cb1bbb429a729b300e065bbc833383
parent75fee3776f2e159d8e52bb13bb4545ac46021512 (diff)
downloadchromium_src-7d1ca4dc9a9b7934b54354033addb8aae240f0c5.zip
chromium_src-7d1ca4dc9a9b7934b54354033addb8aae240f0c5.tar.gz
chromium_src-7d1ca4dc9a9b7934b54354033addb8aae240f0c5.tar.bz2
Disabled plugin broker infobar on Chrome OS for Widevine plingin as well (M26+).
BUG=185767 TEST=in M26, make sure we don't see "<plugin> on <site> wants to access your computer" message on netflix site Review URL: https://codereview.chromium.org/12502003 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@186302 0039d316-1c4b-4281-b951-d872f2087c98
-rw-r--r--chrome/browser/pepper_broker_infobar_delegate.cc10
1 files changed, 6 insertions, 4 deletions
diff --git a/chrome/browser/pepper_broker_infobar_delegate.cc b/chrome/browser/pepper_broker_infobar_delegate.cc
index 77854bd..6effc79 100644
--- a/chrome/browser/pepper_broker_infobar_delegate.cc
+++ b/chrome/browser/pepper_broker_infobar_delegate.cc
@@ -30,6 +30,7 @@ const char kPpapiBrokerLearnMoreUrl[] =
#if defined(OS_CHROMEOS)
const char kNetflixPluginFileName[] = "libnetflixplugin2.so";
+const char kWidevinePluginFileName[] = "libwidevinecdmadapter.so";
#endif
using content::OpenURLParams;
@@ -54,10 +55,11 @@ void PepperBrokerInfoBarDelegate::Create(
TabSpecificContentSettings::FromWebContents(web_contents);
#if defined(OS_CHROMEOS)
- // On ChromeOS, we're ok with granting broker access to Netflix plugin, since
- // it can only come installed with the OS.
- if (plugin_path.BaseName().value() ==
- FILE_PATH_LITERAL(kNetflixPluginFileName)) {
+ // On ChromeOS, we're ok with granting broker access to Netflix and Widevine
+ // plugin, since it can only come installed with the OS.
+ base::FilePath plugin_file_name = plugin_path.BaseName();
+ if (plugin_file_name.value() == FILE_PATH_LITERAL(kNetflixPluginFileName) ||
+ plugin_file_name.value() == FILE_PATH_LITERAL(kWidevinePluginFileName)) {
tab_content_settings->SetPepperBrokerAllowed(true);
callback.Run(true);
return;